@@ -18,14 +18,14 @@ class ddr_api_test(unittest.TestCase):
             self.assertTrue((str(e.message).startswith("You are not authorized to access this resource.")))
 
     def test_successful_call(self):
-        url = "https://devapp.datadistillr.io/v1/results/27921499"
-        auth_token = "DDR1-HMAC-SHA256 Credential=ae63b76871914f18550704ebe2191dcd " \
-                     "Signature=fc02eb28903474d21ad3c38ccd7a8bb519c3c9aebf6609ad5603d0ab09f0a31e "
+        url = "https://app.datadistillr.io/v1/results/614364805"
+        auth_token = "DDR1-HMAC-SHA256 Credential=b3880a85e304170f1b24ad8d3334845f " \
+                     "Signature=f8c78f8b2e6b69ad79a44bfb441b2b6e06ec0b037184ecbd44cf45f2c82c78b6"
         df = ddr.datadistillr.get_dataframe(url, auth_token)
-        self.assertEqual(df['ip'].count(), 1000)
-        self.assertEqual(df['datetime'].count(), 1000)
-        self.assertEqual(df['duration'].count(), 1000)
-        self.assertEqual(df.shape, (1000, 3))
+        self.assertEqual(df['connection_client_host'].count(), 520)
+        self.assertEqual(df['city'].count(), 520)
+        self.assertEqual(df['country'].count(), 520)
+        self.assertEqual(df.shape, (520, 3))
 
 
 if __name__ == '__main__':
